@@ -1,21 +1,18 @@
 #ifndef _about_h__
 #define _about_h__
 
-#include <QWidget>
 #include <QVBoxLayout>
+#include <QWidget>
 
-class About : public QWidget
-{
-	Q_OBJECT
+class About : public QWidget {
+    Q_OBJECT
 
-	public:
-		About();
-		~About();
+  public:
+    About();
+    ~About();
 
-	private:
-		QVBoxLayout *lay;
+  private:
+    QVBoxLayout *lay;
 };
 
-
 #endif // _about_h__
-
