@@ -2,11 +2,8 @@
 #include "BigView.h"
 #include "TDeviceManager.h"
 
-
-BigViewCheckBox::BigViewCheckBox(const QString& channelID) :
-    ConfigCheckBox("", "bigviewChecked/" + channelID),
-    channelID(channelID)
-{
+BigViewCheckBox::BigViewCheckBox(const QString &channelID)
+    : ConfigCheckBox("", "bigviewChecked/" + channelID), channelID(channelID) {
     connect(this, &ConfigCheckBox::changed, this, &BigViewCheckBox::onChange);
     onChange(isChecked());
 }
@@ -15,9 +12,7 @@ void BigViewCheckBox::onChange(bool checked) {
 
     if (checked) {
         BigView::instance().addChannel(channelID);
-    }
-    else {
+    } else {
         BigView::instance().removeChannel(channelID);
     }
-
 }
\ No newline at end of file
