@@ -1,16 +1,12 @@
 #include "DaemonThreadManager.h"
 
-
-DaemonThreadManager::DaemonThreadManager() {
-
-}
+DaemonThreadManager::DaemonThreadManager() {}
 
 void DaemonThreadManager::addThread(DaemonThread *t) {
 
     mutex.lock();
     threads.append(t);
     mutex.unlock();
-
 }
 
 void DaemonThreadManager::removeThread(DaemonThread *t) {
@@ -18,7 +14,6 @@ void DaemonThreadManager::removeThread(DaemonThread *t) {
     mutex.lock();
     threads.removeOne(t);
     mutex.unlock();
-
 }
 
 void DaemonThreadManager::shutdown() {
@@ -36,5 +31,4 @@ void DaemonThreadManager::shutdown() {
     threads.clear();
 
     mutex.unlock();
-
 }
