@@ -1,11 +1,8 @@
 #include "GraphViewCheckBox.h"
 #include "GraphView.h"
 
-
-GraphViewCheckBox::GraphViewCheckBox(const QString& channelId) :
-    ConfigCheckBox("", "graphChecked/" + channelId),
-    channelId(channelId)
-{
+GraphViewCheckBox::GraphViewCheckBox(const QString &channelId)
+    : ConfigCheckBox("", "graphChecked/" + channelId), channelId(channelId) {
     connect(this, &ConfigCheckBox::changed, this, &GraphViewCheckBox::onChange);
     onChange(isChecked());
 }
@@ -14,9 +11,7 @@ void GraphViewCheckBox::onChange(bool checked) {
 
     if (checked) {
         GraphView::instance().addChannel(channelId);
-    }
-    else {
+    } else {
         GraphView::instance().removeChannel(channelId);
     }
-
 }
\ No newline at end of file
