@@ -1,29 +1,19 @@
 #include <stdio.h>
 
-#include "LogConversionRunnable.h"
 #include "ConfigPanel.h"
+#include "LogConversionRunnable.h"
 #include "usbtenki_version.h"
 
-
 static void progress_callback(uint32_t done, uint32_t total, void *user_data) {
 
     LogConversionRunnable *r = (LogConversionRunnable *)user_data;
     emit r->progress(done, total);
-
 }
 
+LogConversionRunnable::LogConversionRunnable(const QString &inputPath, const QString &outputPath)
+    : inputPath(inputPath), outputPath(outputPath), csvopt(ConfigPanel::instance().getCSVOptions()) {}
 
-LogConversionRunnable::LogConversionRunnable(const QString& inputPath, const QString& outputPath) :
-    inputPath(inputPath),
-    outputPath(outputPath),
-    csvopt(ConfigPanel::instance().getCSVOptions())
-{
-
-}
-
-LogConversionRunnable::~LogConversionRunnable() {
-
-}
+LogConversionRunnable::~LogConversionRunnable() {}
 
 void LogConversionRunnable::run() {
 
@@ -53,5 +43,4 @@ void LogConversionRunnable::run() {
 
     fclose(output);
     datalog_close(datalog);
-
 }
