@@ -1,28 +1,27 @@
-#include <QVBoxLayout>
-#include <QHBoxLayout>
-#include <QGridLayout>
-#include <QGroupBox>
-#include <QPushButton>
-#include <QIcon>
-#include <QSettings>
-#include <QDir>
-#include <QFileDialog>
-#include <QMessageBox>
-#include <QFileInfo>
 #include <QDateTime>
 #include <QDebug>
+#include <QDir>
+#include <QFileDialog>
+#include <QFileInfo>
+#include <QGridLayout>
+#include <QGroupBox>
+#include <QHBoxLayout>
+#include <QIcon>
+#include <QMessageBox>
+#include <QPushButton>
+#include <QSettings>
+#include <QVBoxLayout>
 
-#include "LoggingPanel.h"
+#include "Config.h"
 #include "ConfigPanel.h"
-#include "TDeviceManager.h"
 #include "DataSourceCheckBox.h"
+#include "LoggingPanel.h"
+#include "TDeviceManager.h"
 #include "TextViewer.h"
 
-
-#define EXISTS_OVERWRITE	0
-#define EXISTS_APPEND		1
-#define EXISTS_CONFIRM		2
-
+#define EXISTS_OVERWRITE 0
+#define EXISTS_APPEND 1
+#define EXISTS_CONFIRM 2
 
 LoggingPanel::LoggingPanel() {
 
@@ -56,13 +55,13 @@ LoggingPanel::LoggingPanel() {
     QHBoxLayout *selectButtonsLayout = new QHBoxLayout();
     selectButtonsWidget->setLayout(selectButtonsLayout);
 
-	selectButtonsLayout->addWidget(selectAllButton);
-	selectButtonsLayout->addWidget(selectNoneButton);
-	selectButtonsLayout->addStretch();
+    selectButtonsLayout->addWidget(selectAllButton);
+    selectButtonsLayout->addWidget(selectNoneButton);
+    selectButtonsLayout->addStretch();
 
     leftColumnLayout->addWidget(selectButtonsWidget);
 
-	// Add channels
+    // Add channels
     QWidget *channelsWidget = new QWidget();
     channelsLayout = new QVBoxLayout();
     channelsWidget->setLayout(channelsLayout);
@@ -74,15 +73,15 @@ LoggingPanel::LoggingPanel() {
     mathChannelsWidget->setLayout(mathChannelsLayout);
     leftColumnLayout->addWidget(mathChannelsWidget);
 
-	TDeviceManager *deviceManager = &(TDeviceManager::instance());
-	connect(deviceManager, &TDeviceManager::deviceAdded, this, &LoggingPanel::addDevice);
-	connect(deviceManager, &TDeviceManager::deviceRemoved, this, &LoggingPanel::removeDevice);
+    TDeviceManager *deviceManager = &(TDeviceManager::instance());
+    connect(deviceManager, &TDeviceManager::deviceAdded, this, &LoggingPanel::addDevice);
+    connect(deviceManager, &TDeviceManager::deviceRemoved, this, &LoggingPanel::removeDevice);
 
-    QVector<TDevice*> devices = deviceManager->getDevices();
-	for (int i = 0; i < devices.size(); i++) {
+    QVector<TDevice *> devices = deviceManager->getDevices();
+    for (int i = 0; i < devices.size(); i++) {
         TDevice *device = devices[i];
-		addDevice(devices[i]);
-	}
+        addDevice(devices[i]);
+    }
 
     leftColumnLayout->addStretch();
 
@@ -90,7 +89,7 @@ LoggingPanel::LoggingPanel() {
 
     QWidget *rightColumn = new QWidget();
     QVBoxLayout *rightColumnLayout = new QVBoxLayout();
-    rightColumn ->setLayout(rightColumnLayout);
+    rightColumn->setLayout(rightColumnLayout);
 
     // Settings
 
@@ -101,40 +100,38 @@ LoggingPanel::LoggingPanel() {
     settingsBox->setLayout(settingsBoxLayout);
 
     ConfigComboBox *separatorComboBox = new FieldSeparatorComboBox();
-	settingsBoxLayout->addWidget(new QLabel(tr("Field separator:")), y, 0 );
-	settingsBoxLayout->addWidget(separatorComboBox, y, 1);
+    settingsBoxLayout->addWidget(new QLabel(tr("Field separator:")), y, 0);
+    settingsBoxLayout->addWidget(separatorComboBox, y, 1);
 
     ConfigComboBox *decimalComboBox = new DecimalPointComboBox();
-    settingsBoxLayout->addWidget(new QLabel(tr("Decimal point:")), y, 2 );
-	settingsBoxLayout->addWidget(decimalComboBox, y, 3);
-	y++;
+    settingsBoxLayout->addWidget(new QLabel(tr("Decimal point:")), y, 2);
+    settingsBoxLayout->addWidget(decimalComboBox, y, 3);
+    y++;
 
     ConfigComboBox *timeFormatComboBox = new TimeFormatComboBox();
-	settingsBoxLayout->addWidget(new QLabel(tr("Timestamps:")), y, 0 );
-	settingsBoxLayout->addWidget(timeFormatComboBox, y, 1, 1, 4);
-	y++;
+    settingsBoxLayout->addWidget(new QLabel(tr("Timestamps:")), y, 0);
+    settingsBoxLayout->addWidget(timeFormatComboBox, y, 1, 1, 4);
+    y++;
 
     ConfigComboBox *errorComboBox = new ErrorStringComboBox();
-	settingsBoxLayout->addWidget(new QLabel(tr("On error:")), y, 0);
-	settingsBoxLayout->addWidget(errorComboBox, y, 1, 1, 4);
-	y++;
+    settingsBoxLayout->addWidget(new QLabel(tr("On error:")), y, 0);
+    settingsBoxLayout->addWidget(errorComboBox, y, 1, 1, 4);
+    y++;
 
-    existingFileComboBox = new ConfigComboBox("logger/if_file_exists",
-        {
-            "Overwrite file without confirmation",
-            "Append to file without confirmation",
-            "Overwrite file with confirmation",
-            "Append to file with confirmation",
-        }
-    );
+    existingFileComboBox = new ConfigComboBox("logger/if_file_exists", {
+                                                                           "Overwrite file without confirmation",
+                                                                           "Append to file without confirmation",
+                                                                           "Overwrite file with confirmation",
+                                                                           "Append to file with confirmation",
+                                                                       });
 
     settingsBoxLayout->addWidget(new QLabel(tr("If file exists:")));
-	settingsBoxLayout->addWidget(existingFileComboBox, y, 1, 1, 4);
-	y++;
+    settingsBoxLayout->addWidget(existingFileComboBox, y, 1, 1, 4);
+    y++;
 
     intervalSpinBox = new QDoubleSpinBox();
-	intervalSpinBox->setSuffix(" s");
-	intervalSpinBox->setDecimals(3);
+    intervalSpinBox->setSuffix(" s");
+    intervalSpinBox->setDecimals(3);
     connect(intervalSpinBox, SIGNAL(valueChanged(double)), this, SLOT(onIntervalSelected(double)));
     settingsBoxLayout->addWidget(new QLabel(tr("Interval:")), y, 0);
     settingsBoxLayout->addWidget(intervalSpinBox, y, 1, 1, 1);
@@ -142,10 +139,10 @@ LoggingPanel::LoggingPanel() {
 
     y++;
 
-	interval = -1;
-	setGlobalInterval(ConfigPanel::instance().getInterval());
+    interval = -1;
+    setGlobalInterval(ConfigPanel::instance().getInterval());
 
-	connect(&(ConfigPanel::instance()), &ConfigPanel::intervalChanged, this, &LoggingPanel::setGlobalInterval);
+    connect(&(ConfigPanel::instance()), &ConfigPanel::intervalChanged, this, &LoggingPanel::setGlobalInterval);
 
     // Output path
 
@@ -155,12 +152,12 @@ LoggingPanel::LoggingPanel() {
     QGridLayout *outputPathBoxLayout = new QGridLayout();
     outputPathBox->setLayout(outputPathBoxLayout);
 
-	QPushButton *outputBrowseButton = new QPushButton(QIcon(":fileopen.png"), tr("Browse..."));
+    QPushButton *outputBrowseButton = new QPushButton(QIcon(":fileopen.png"), tr("Browse..."));
     connect(outputBrowseButton, &QPushButton::clicked, this, &LoggingPanel::browseOutputFile);
-	outputPathBoxLayout->addWidget(outputBrowseButton, y, 0, 1, 1);
+    outputPathBoxLayout->addWidget(outputBrowseButton, y, 0, 1, 1);
 
-	outputPathLineEdit = new ConfigLineEdit("logger/filename");
-	outputPathBoxLayout->addWidget(outputPathLineEdit, y, 1, 1, 4);
+    outputPathLineEdit = new ConfigLineEdit("logger/filename");
+    outputPathBoxLayout->addWidget(outputPathLineEdit, y, 1, 1, 4);
 
     y++;
 
@@ -176,11 +173,11 @@ LoggingPanel::LoggingPanel() {
     QHBoxLayout *controlBoxLayout = new QHBoxLayout();
     controlBox->setLayout(controlBoxLayout);
 
-	startButton = new QPushButton(QIcon(":record.png"), tr("Start"));
+    startButton = new QPushButton(QIcon(":record.png"), tr("Start"));
     connect(startButton, &QPushButton::clicked, this, &LoggingPanel::startLogging);
     controlBoxLayout->addWidget(startButton);
 
-	stopButton = new QPushButton(QIcon(":stop.png"), tr("Stop"));
+    stopButton = new QPushButton(QIcon(":stop.png"), tr("Stop"));
     connect(stopButton, &QPushButton::clicked, this, &LoggingPanel::stopLogging);
     stopButton->setEnabled(false);
     controlBoxLayout->addWidget(stopButton);
@@ -231,194 +228,174 @@ LoggingPanel::LoggingPanel() {
 
     mainLayout->addWidget(leftColumn);
     mainLayout->addWidget(rightColumn);
-
 }
 
 LoggingPanel::~LoggingPanel() {
     // Singleton: lives forever
 }
 
-bool LoggingPanel::isRunning() {
-    return (thread != nullptr);
-}
+bool LoggingPanel::isRunning() { return (thread != nullptr); }
 
 void LoggingPanel::addDevice(const TDevice *device) {
 
-	if (device->isTicker()) {
-		return;
-	}
+    if (device->isTicker()) {
+        return;
+    }
 
-	const QString& serial = device->serialNumber;
-	QVector<DataSourceCheckBox*> *checkBoxes = checkBoxesByDevice.value(serial);
+    const QString &serial = device->serialNumber;
+    QVector<DataSourceCheckBox *> *checkBoxes = checkBoxesByDevice.value(serial);
 
-	if (checkBoxes) {
-		// Device already added
-		return;
-	}
+    if (checkBoxes) {
+        // Device already added
+        return;
+    }
 
     QVBoxLayout *layout = device->isMath() ? mathChannelsLayout : channelsLayout;
-	const int n = device->channels.size();
-	checkBoxes = new QVector<DataSourceCheckBox*>(n);
-	checkBoxesByDevice.insert(serial, checkBoxes);
-
-	for (int i = 0; i < n; i++) {
-		TChannel *channel = device->channels[i];
-		DataSourceCheckBox *cb = new DataSourceCheckBox(channel);
-		layout->addWidget(cb);
-		checkBoxes->replace(i, cb);
-	}
+    const int n = device->channels.size();
+    checkBoxes = new QVector<DataSourceCheckBox *>(n);
+    checkBoxesByDevice.insert(serial, checkBoxes);
 
+    for (int i = 0; i < n; i++) {
+        TChannel *channel = device->channels[i];
+        DataSourceCheckBox *cb = new DataSourceCheckBox(channel);
+        layout->addWidget(cb);
+        checkBoxes->replace(i, cb);
+    }
 }
 
 void LoggingPanel::removeDevice(const TDevice *device) {
 
-	const QString& serial = device->serialNumber;
-	QVector<DataSourceCheckBox*> *checkBoxes = checkBoxesByDevice.value(serial);
+    const QString &serial = device->serialNumber;
+    QVector<DataSourceCheckBox *> *checkBoxes = checkBoxesByDevice.value(serial);
 
-	if (!checkBoxes) {
-		// Device not found
-		return;
-	}
+    if (!checkBoxes) {
+        // Device not found
+        return;
+    }
 
     QVBoxLayout *layout = device->isMath() ? mathChannelsLayout : channelsLayout;
-	const int n = checkBoxes->size();
+    const int n = checkBoxes->size();
 
-	for (int i = 0; i < n; i++) {
-		DataSourceCheckBox *cb = checkBoxes->at(i);
-		layout->removeWidget(cb);
-		cb->setVisible(false);
-		delete cb;
-	}
-
-	delete checkBoxes;
-	checkBoxesByDevice.remove(serial);
+    for (int i = 0; i < n; i++) {
+        DataSourceCheckBox *cb = checkBoxes->at(i);
+        layout->removeWidget(cb);
+        cb->setVisible(false);
+        delete cb;
+    }
 
+    delete checkBoxes;
+    checkBoxesByDevice.remove(serial);
 }
 
 void LoggingPanel::setAllSelected(bool selected) {
 
-	QMapIterator<QString, QVector<DataSourceCheckBox*>*> it(checkBoxesByDevice);
-
-	while (it.hasNext()) {
-		it.next();
-		QVector<DataSourceCheckBox*> *sources = it.value();
-		for (int i = 0; i < sources->size(); i++) {
-			DataSourceCheckBox *cb = sources->at(i);
-			cb->setChecked(selected);
-		}
-	}
+    QMapIterator<QString, QVector<DataSourceCheckBox *> *> it(checkBoxesByDevice);
 
+    while (it.hasNext()) {
+        it.next();
+        QVector<DataSourceCheckBox *> *sources = it.value();
+        for (int i = 0; i < sources->size(); i++) {
+            DataSourceCheckBox *cb = sources->at(i);
+            cb->setChecked(selected);
+        }
+    }
 }
 
 void LoggingPanel::setIntervalMultiple(int m) {
 
-	if (m <= 0) {
-		m = 1;
-	}
+    if (m <= 0) {
+        m = 1;
+    }
 
-	intervalMultiple = m;
-	interval = m * globalInterval;
+    intervalMultiple = m;
+    interval = m * globalInterval;
 
-	double s = ((double)interval) / 1000.0;
-	intervalSpinBox->setValue(s);
-
-	QSettings settings;
-	settings.setValue("logger/sample_interval_multiple", m);
+    double s = ((double)interval) / 1000.0;
+    intervalSpinBox->setValue(s);
 
+    QSettings settings;
+    settings.setValue("logger/sample_interval_multiple", m);
 }
 
 void LoggingPanel::updateIntervalSpinBox() {
 
-	double global_s = ((double)globalInterval) / 1000.0;
-	double log_s = ((double)interval) / 1000.0;
+    double global_s = ((double)globalInterval) / 1000.0;
+    double log_s = ((double)interval) / 1000.0;
 
-	intervalSpinBox->setMinimum(global_s);
-	intervalSpinBox->setSingleStep(global_s);
-	intervalSpinBox->setRange(global_s, global_s * 0x1p14);
-	intervalSpinBox->setValue(log_s);
+    intervalSpinBox->setMinimum(global_s);
+    intervalSpinBox->setSingleStep(global_s);
+    intervalSpinBox->setRange(global_s, global_s * 0x1p14);
+    intervalSpinBox->setValue(log_s);
 
     intervalSpinBox->setEnabled(true);
-
 }
 
-void LoggingPanel::showError(const QString& message, const QString& hint) {
+void LoggingPanel::showError(const QString &message, const QString &hint) {
 
-	QMessageBox msgBox;
+    QMessageBox msgBox;
     msgBox.setWindowTitle("Error");
-	msgBox.setText(message);
-	msgBox.setInformativeText(hint);
-	msgBox.setStandardButtons(QMessageBox::Ok);
-	msgBox.setIcon(QMessageBox::Critical);
-	msgBox.exec();
-
+    msgBox.setText(message);
+    msgBox.setInformativeText(hint);
+    msgBox.setStandardButtons(QMessageBox::Ok);
+    msgBox.setIcon(QMessageBox::Critical);
+    msgBox.exec();
 }
 
-void LoggingPanel::addMessage(const QString& message) {
-
-	QDateTime now = QDateTime::currentDateTime();
-	messageTextEdit->append(now.toString("(yyyy-MM-dd hh:mm:ss)  ") + message);
+void LoggingPanel::addMessage(const QString &message) {
 
+    QDateTime now = QDateTime::currentDateTime();
+    messageTextEdit->append(now.toString("(yyyy-MM-dd hh:mm:ss)  ") + message);
 }
 
-void LoggingPanel::selectAll() {
+void LoggingPanel::selectAll() { setAllSelected(true); }
 
-    setAllSelected(true);
-
-}
-
-void LoggingPanel::selectNone() {
-
-    setAllSelected(false);
-
-}
+void LoggingPanel::selectNone() { setAllSelected(false); }
 
 void LoggingPanel::browseOutputFile() {
 
     QString path = outputPathLineEdit->text().trimmed();
 
-	if (path.isEmpty()) {
-		path = QDir::homePath();
-	}
+    if (path.isEmpty()) {
+        path = QDir::homePath();
+    }
 
-	path = QFileDialog::getSaveFileName(this, tr("Save Text Log"), path, "Text Logs (*.csv)");
+    path = QFileDialog::getSaveFileName(this, tr("Save Text Log"), path, "Text Logs (*.csv)");
 
-	if (path.size()) {
+    if (path.size()) {
         if (!path.endsWith(".csv", Qt::CaseInsensitive)) {
             path += ".csv";
         }
-		outputPathLineEdit->setTextAndSave(path);
-	}
-
+        outputPathLineEdit->setTextAndSave(path);
+    }
 }
 
 void LoggingPanel::setGlobalInterval(int ms) {
 
     QSettings settings;
-	globalInterval = ms;
+    globalInterval = ms;
 
-	if (interval > 0) {
-		intervalMultiple = interval / ms;
-		if (intervalMultiple == 0) { intervalMultiple = 1; }
-		settings.setValue("logger/sample_interval_multiple", intervalMultiple);
-	}
-    else {
+    if (interval > 0) {
+        intervalMultiple = interval / ms;
+        if (intervalMultiple == 0) {
+            intervalMultiple = 1;
+        }
+        settings.setValue("logger/sample_interval_multiple", intervalMultiple);
+    } else {
         intervalMultiple = settings.value("logger/sample_interval_multiple", 1).toInt();
     }
 
-	interval = globalInterval * intervalMultiple;
+    interval = globalInterval * intervalMultiple;
 
     if (!thread) {
         updateIntervalSpinBox();
     }
-
 }
 
 void LoggingPanel::onIntervalSelected(double s) {
 
-	double ms = s * 1000.0;
-	intervalMultiple = ((int)round(ms)) / globalInterval;
-	setIntervalMultiple(intervalMultiple);
-
+    double ms = s * 1000.0;
+    intervalMultiple = ((int)round(ms)) / globalInterval;
+    setIntervalMultiple(intervalMultiple);
 }
 
 void LoggingPanel::showLogViewer() {
@@ -427,37 +404,30 @@ void LoggingPanel::showLogViewer() {
         return;
     }
 
-	logViewer = new TextViewer(outputPathLineEdit->text(), "Log File");
+    logViewer = new TextViewer(outputPathLineEdit->text(), "Log File");
     connect(logViewer, &QDialog::finished, this, &LoggingPanel::onLogViewerFinished);
-	logViewer->show();
-
+    logViewer->show();
 }
 
 void LoggingPanel::onLogViewerFinished(int result) {
 
     delete logViewer;
     logViewer = nullptr;
-
 }
 
-void LoggingPanel::clearMessages() {
-
-    messageTextEdit->clear();
-
-}
+void LoggingPanel::clearMessages() { messageTextEdit->clear(); }
 
 void LoggingPanel::saveMessages() {
-    
-	QString path = QFileDialog::getSaveFileName(this, tr("Save Messages"), "", "Text Files (*.txt)" );
 
-	if (path.size()) {
-		QFile file;
-		file.setFileName(path);
-		file.open(QIODevice::WriteOnly | QIODevice::Text);
-		file.write(messageTextEdit->toPlainText().toUtf8());
-		file.close();
-	}
+    QString path = QFileDialog::getSaveFileName(this, tr("Save Messages"), "", "Text Files (*.txt)");
 
+    if (path.size()) {
+        QFile file;
+        file.setFileName(path);
+        file.open(QIODevice::WriteOnly | QIODevice::Text);
+        file.write(messageTextEdit->toPlainText().toUtf8());
+        file.close();
+    }
 }
 
 void LoggingPanel::startLogging() {
@@ -468,10 +438,10 @@ void LoggingPanel::startLogging() {
 
     QVector<QString> channelIds;
 
-    QMapIterator<QString, QVector<DataSourceCheckBox*>*> it(checkBoxesByDevice);
+    QMapIterator<QString, QVector<DataSourceCheckBox *> *> it(checkBoxesByDevice);
     while (it.hasNext()) {
         it.next();
-        QVector<DataSourceCheckBox*> *checkBoxes = it.value();
+        QVector<DataSourceCheckBox *> *checkBoxes = it.value();
         for (int i = 0; i < checkBoxes->size(); i++) {
             DataSourceCheckBox *cb = checkBoxes->at(i);
             if (cb->isChecked()) {
@@ -494,33 +464,44 @@ void LoggingPanel::startLogging() {
 
     int existingFileAction = existingFileComboBox->currentIndex();
     bool append = existingFileAction % 2;
-	QFileInfo qf = QFileInfo(path);
+    QFileInfo qf = QFileInfo(path);
+
+    const bool preventSleep = loadEnablePreventSleepDuringLogging();
+
+    if (preventSleep) {
+#if defined(Q_OS_WIN)
+        addMessage("System will stay awake during logging, but screen may turn off");
+#elif defined(Q_OS_OSX)
+        addMessage("System will stay awake during logging, but screen may turn off");
+#else
+        addMessage("Sleep prevention not supported on this OS. Please disable automatic sleep in system settings.");
+#endif
+    }
 
     addMessage("Logging started: " + path);
 
-	if (qf.isFile()) {
+    if (qf.isFile()) {
 
-		if (!qf.isWritable()) {
+        if (!qf.isWritable()) {
             addMessage("ERROR: Cannot write to log file");
-			showError(tr("File is not writeable."), tr("Select another file or check permissions."));
-			return;
-		}
+            showError(tr("File is not writeable."), tr("Select another file or check permissions."));
+            return;
+        }
 
-		addMessage("Warning: File already exists");
+        addMessage("Warning: File already exists");
 
-		if (existingFileAction & EXISTS_CONFIRM) {
-			QMessageBox msgBox;
-			msgBox.setText("File already exists. Continue?");
-			msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::Cancel);	
-			msgBox.setIcon(QMessageBox::Warning);
-			int selection = msgBox.exec();
-			if (selection != QMessageBox::Yes) {
-				addMessage("Logging cancelled by user");
-				return;
-			}
-		}
-
-	}
+        if (existingFileAction & EXISTS_CONFIRM) {
+            QMessageBox msgBox;
+            msgBox.setText("File already exists. Continue?");
+            msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::Cancel);
+            msgBox.setIcon(QMessageBox::Warning);
+            int selection = msgBox.exec();
+            if (selection != QMessageBox::Yes) {
+                addMessage("Logging cancelled by user");
+                return;
+            }
+        }
+    }
 
     startButton->setEnabled(false);
     stopButton->setEnabled(true);
@@ -541,7 +522,6 @@ void LoggingPanel::startLogging() {
     counterLabel->setText("0");
 
     emit loggingStatusChanged(true);
-
 }
 
 void LoggingPanel::stopLogging() {
@@ -550,22 +530,26 @@ void LoggingPanel::stopLogging() {
         return;
     }
 
-    thread->shutdown();
+    const bool preventSleep = loadEnablePreventSleepDuringLogging();
 
+    if (preventSleep) {
+#if defined(Q_OS_WIN)
+        addMessage("System sleep prevention disabled - normal power settings restored");
+#elif defined(Q_OS_OSX)
+        addMessage("System sleep prevention disabled - normal power settings restored");
+#endif
+    }
+
+    thread->shutdown();
 }
 
 void LoggingPanel::onThreadError(int error) {
 
     addMessage("ERROR: Cannot write to log file");
     showError("Cannot write to log file.", QString());
-
 }
 
-void LoggingPanel::onThreadWrite(qulonglong n) {
-
-    counterLabel->setText(QString::number(n));
-
-}
+void LoggingPanel::onThreadWrite(qulonglong n) { counterLabel->setText(QString::number(n)); }
 
 void LoggingPanel::onThreadFinished() {
 
@@ -586,5 +570,4 @@ void LoggingPanel::onThreadFinished() {
     updateIntervalSpinBox();
 
     emit loggingStatusChanged(false);
-
 }
