@@ -1,18 +1,16 @@
 #include <QSettings>
 #include <stdio.h>
 
-#include "QuantityFormat.h"
 #include "ConfigPanel.h"
-
+#include "QuantityFormat.h"
 
 QuantityFormat::QuantityFormat() {
 
-    ConfigPanel& config = ConfigPanel::instance();
+    ConfigPanel &config = ConfigPanel::instance();
     connect(&config, &ConfigPanel::fractionalDigitsChanged, this, &QuantityFormat::setFractionalDigits);
 
     csvopt = &config.getCSVOptions();
     setFractionalDigits(csvopt->frac_digits);
-
 }
 
 void QuantityFormat::toPreferredUnit(Quantity &qty) const {
@@ -21,7 +19,6 @@ void QuantityFormat::toPreferredUnit(Quantity &qty) const {
     unit_t pref = csvopt->units[cat];
 
     quantity_convert_to_unit(&qty, pref);
-
 }
 
 QString QuantityFormat::toString(double value) const {
@@ -30,18 +27,12 @@ QString QuantityFormat::toString(double value) const {
     result.sprintf(format, value);
 
     return result;
-
 }
 
-QString QuantityFormat::toString(const Quantity &qty) const {
-
-    return toString(quantity_value_as_double(&qty));
-
-}
+QString QuantityFormat::toString(const Quantity &qty) const { return toString(quantity_value_as_double(&qty)); }
 
 void QuantityFormat::setFractionalDigits(int n) {
 
     sprintf(format, "%%.%df", n);
     csvopt->frac_digits = n;
-
 }
