@@ -1,9 +1,8 @@
-#include <QScrollBar>
 #include <QDebug>
+#include <QScrollBar>
 
 #include "SmartScrollArea.h"
 
-
 SmartScrollArea::SmartScrollArea() {
 
     connect(horizontalScrollBar(), &QScrollBar::sliderReleased, this, &SmartScrollArea::saveHorizontalPosition);
@@ -11,28 +10,16 @@ SmartScrollArea::SmartScrollArea() {
 
     saveHorizontalPosition();
     saveVerticalPosition();
-
 }
 
-SmartScrollArea::~SmartScrollArea() {
-
-}
+SmartScrollArea::~SmartScrollArea() {}
 
 void SmartScrollArea::restoreLastPosition() {
 
     horizontalScrollBar()->setSliderPosition(hPos);
     verticalScrollBar()->setSliderPosition(vPos);
-
 }
 
-void SmartScrollArea::saveHorizontalPosition() {
+void SmartScrollArea::saveHorizontalPosition() { hPos = horizontalScrollBar()->sliderPosition(); }
 
-    hPos = horizontalScrollBar()->sliderPosition();
-
-}
-
-void SmartScrollArea::saveVerticalPosition() {
-
-    vPos = verticalScrollBar()->sliderPosition();
-
-}
+void SmartScrollArea::saveVerticalPosition() { vPos = verticalScrollBar()->sliderPosition(); }
