@@ -965,9 +965,12 @@ static int handle_device_header(Context *context, char *data, size_t len, Device
         p += 2;
 
         if (!(flags & DEVICE_FLAG_CALPOINTS)) {
+            channel->calpoints_count = 0;
             continue;
         }
 
+        channel->calpoints_count = CAL_POINTS_COUNT;
+
         for (Point *point = channel->calpoints; point < channel->calpoints + CAL_POINTS_COUNT; point++) {
             memcpy(&point->x_bits, p, sizeof(uint64_t));
             point->x_bits = be64toh(point->x_bits);
